==> kibana-7.9.1.tgz: kibana/src/plugins/vis_type_timelion/server/routes/validate_es.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validateEsRoute = validateEsRoute;

var _lodash = _interopRequireDefault(require("lodash"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
function validateEsRoute(router) {
  router.get({
    path: '/api/timelion/validate/es',
    validate: false
  }, async function (context, request, response) {
    const uiSettings = await context.core.uiSettings.client.getAll();
    const {
      callAsCurrentUser
    } = context.core.elasticsearch.legacy.client;
    const timefield = uiSettings['timelion:es.timefield'];
    const body = {
      index: uiSettings['es.default_index'],
      body: {
        aggs: {
          maxAgg: {
            max: {
              field: timefield
            }
          },
          minAgg: {
            min: {
              field: timefield
            }
          }
        },
        size: 0
      }
    };
    let resp = {};

    try {
      resp = await callAsCurrentUser('search', body);
    } catch (errResp) {
      resp = errResp;
    }

    if (_lodash.default.has(resp, 'aggregations.maxAgg.value') && _lodash.default.has(resp, 'aggregations.minAgg.value')) {
      return response.ok({
        body: {
          ok: true,
          field: timefield,
          min: _lodash.default.get(resp, 'aggregations.minAgg.value'),
          max: _lodash.default.get(resp, 'aggregations.maxAgg.value')
        }
      });
    }

    return response.ok({
      body: {
        ok: false,
        resp
      }
    });
  });
}

==> kibana-7.10.0.tgz: kibana/src/plugins/vis_type_timelion/server/routes/validate_es.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validateEsRoute = validateEsRoute;

var _lodash = _interopRequireDefault(require("lodash"));

var _server = require("../../../data/server");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
function validateEsRoute(router, core) {
  router.get({
    path: '/api/timelion/validate/es',
    validate: false
  }, async function (context, request, response) {
    const uiSettings = await context.core.uiSettings.client.getAll();
    const deps = (await core.getStartServices())[1];
    const timefield = uiSettings['timelion:es.timefield'];
    const body = {
      params: {
        index: uiSettings['es.default_index'],
        body: {
          aggs: {
            maxAgg: {
              max: {
                field: timefield
              }
            },
            minAgg: {
              min: {
                field: timefield
              }
            }
          },
          size: 0
        }
      }
    };
    let resp;

    try {
      resp = await deps.data.search.search(context, body, {
        strategy: _server.ES_SEARCH_STRATEGY
      });
      resp = resp.rawResponse;
    } catch (errResp) {
      resp = errResp;
    }

    if (_lodash.default.has(resp, 'aggregations.maxAgg.value') && _lodash.default.has(resp, 'aggregations.minAgg.value')) {
      return response.ok({
        body: {
          ok: true,
          field: timefield,
          min: _lodash.default.get(resp, 'aggregations.minAgg.value'),
          max: _lodash.default.get(resp, 'aggregations.maxAgg.value')
        }
      });
    }

    return response.ok({
      body: {
        ok: false,
        resp
      }
    });
  });
}
